package sequoia;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;

import javax.servlet.ServletConfig;

import org.apache.log4j.Logger;
import org.apache.velocity.app.Velocity;
import org.apache.velocity.servlet.VelocityServlet;


public class VelocityInitializationServlet extends VelocityServlet {
    Logger logger = Logger.getLogger(VelocityInitializationServlet.class);
    
    protected Properties loadConfiguration(ServletConfig config)
            throws IOException, FileNotFoundException {

        //retrieve velocity properties filename 
        String propsFile = config.getInitParameter(INIT_PROPS_KEY);

        Properties p = new Properties();
        if (propsFile != null) {
            String realPath = getServletContext().getRealPath(propsFile);
            if (realPath != null) {
                propsFile = realPath;
            }
            //load velocityproperties
            p.load(new FileInputStream(propsFile));
        }

        String log = p.getProperty(Velocity.RUNTIME_LOG);
        if (log != null) {
            log = getServletContext().getRealPath(log);            
            if (log != null) {
                logger.info("Logger set to " + log);
                System.out.println("Logger set to " + log);
                p.setProperty(Velocity.RUNTIME_LOG, log);
            }
        }

        //determine file resource loader path (possibly relative path)
        String path = p.getProperty(Velocity.FILE_RESOURCE_LOADER_PATH);
        if (path != null) {
            //expand path relative to context root
            path = getServletContext().getRealPath(path);
            if (path != null) {
                //assign expanded path to file loader
                p.setProperty(Velocity.FILE_RESOURCE_LOADER_PATH, path);
            } else {
              log("Path to file resource loader is not null (tried servlet context match).");
            }
        } else {
          log("Path to file resource loader is null!");
        }
        return p;
    }
}